@@ -105,131 +105,63 @@ class AnalogOut(AbstractDwfDeviceSubApi):
 
     ####################################################################################################################
     #                                                                                                                  #
-    #                                               PER-CHANNEL CONFIGURATION                                          #
+    #                                     PER-CHANNEL STATE MACHINE SETTINGS CONFIGURATION                             #
     #                                                                                                                  #
     ####################################################################################################################
 
-    def masterSet(self, channel_index: int, master_channel_index: int) -> None:
-        """Set master status.
-
-        Sets the state machine master of the channel generator.
-
-        Parameters:
-            channel_index (int): The output channel for which to set the master setting.
-                Specify -1 to set all channels.
-            master_channel_index (int): The master channel index.
-
-        Raises:
-            DwfLibraryError: An error occurred while setting the value.
-        """
-        result = self.lib.FDwfAnalogOutMasterSet(self.hdwf, channel_index, master_channel_index)
-        if result != RESULT_SUCCESS:
-            raise self.dwf.exception()
-
-    def masterGet(self, channel_index: int) -> int:
-        """Get master status.
-
-        Parameters:
-            channel_index (int): The output channel for which to get the status.
-
-        Returns:
-            int: The index of the master channel which the channel is configured to follow.
-
-        Raises:
-            DwfLibraryError: An error occurred while getting the value.
-        """
-        c_master_channel_index = typespec_ctypes.c_int()
-        result = self.lib.FDwfAnalogOutMasterGet(self.hdwf, channel_index, c_master_channel_index)
-        if result != RESULT_SUCCESS:
-            raise self.dwf.exception()
-        master_channel_index = c_master_channel_index.value
-        return master_channel_index
-
-    def modeSet(self, channel_index: int, mode: DwfAnalogOutMode) -> None:
-        """Set analog output mode.
-
-        Parameters:
-            channel_index (int): The |AnalogOut| channel.
-            mode (DwfAnalogOutMode): The mode.
-
-        Raises:
-            DwfLibraryError: An error occurred while executing the operation.
-        """
-        result = self.lib.FDwfAnalogOutModeSet(self.hdwf, channel_index, mode.value)
-        if result != RESULT_SUCCESS:
-            raise self.dwf.exception()
-
-    def modeGet(self, channel_index: int) -> DwfAnalogOutMode:
-        """Get analog output mode.
+    def waitInfo(self, channel_index: int) -> Tuple[float, float]:
+        """Get wait info.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            DwfAnalogOutMode: The currently configured analog output mode.
+            Tuple[float, float]: The range of configurable wait durations.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
         """
-        c_mode = typespec_ctypes.DwfAnalogOutMode()
-        result = self.lib.FDwfAnalogOutModeGet(self.hdwf, channel_index, c_mode)
+        c_secMin = typespec_ctypes.c_double()
+        c_secMax = typespec_ctypes.c_double()
+        result = self.lib.FDwfAnalogOutWaitInfo(self.hdwf, channel_index, c_secMin, c_secMax)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        mode = DwfAnalogOutMode(c_mode.value)
-        return mode
+        secMin = c_secMin.value
+        secMax = c_secMax.value
+        return (secMin, secMax)
 
-    def idleInfo(self, channel_index: int) -> List[DwfAnalogOutIdle]:
-        """Get idle info.
+    def waitSet(self, channel_index: int, wait_duration: float) -> None:
+        """Set wait state duration, in seconds.
+
+        Parameters:
+            channel_index (int): The |AnalogOut| channel.
+            wait_duration (float): The wait duration, in seconds.
+
+        Raises:
+            DwfLibraryError: An error occurred while executing the operation.
+        """
+        result = self.lib.FDwfAnalogOutWaitSet(self.hdwf, channel_index, wait_duration)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+
+    def waitGet(self, channel_index: int) -> float:
+        """Get wait state duration in seconds.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            List[DwfAnalogOutIdle]: A list of options for the channel behavior when idle.
+            float: The currently configured wait duration.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
         """
-        c_idle_bitset = typespec_ctypes.c_int()
-        result = self.lib.FDwfAnalogOutIdleInfo(self.hdwf, channel_index, c_idle_bitset)
+        c_wait_duration = typespec_ctypes.c_double()
+        result = self.lib.FDwfAnalogOutWaitGet(self.hdwf, channel_index, c_wait_duration)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        idle_bitset = c_idle_bitset.value
-        idle_list = [idle for idle in DwfAnalogOutIdle if idle_bitset & (1 << idle.value)]
-        return idle_list
-
-    def idleSet(self, channel_index: int, idle: DwfAnalogOutIdle) -> None:
-        """Set idle behavior.
-
-        Parameters:
-            channel_index (int): The |AnalogOut| channel.
-            idle (DwfAnalogOutIdle): The idle setting.
-
-        Raises:
-            DwfLibraryError: An error occurred while executing the operation.
-        """
-        result = self.lib.FDwfAnalogOutIdleSet(self.hdwf, channel_index, idle.value)
-        if result != RESULT_SUCCESS:
-            raise self.dwf.exception()
-
-    def idleGet(self, channel_index: int) -> DwfAnalogOutIdle:
-        """Get idle behavior.
-
-        Parameters:
-            channel_index (int): The |AnalogOut| channel.
-
-        Returns:
-            DwfAnalogOutIdle: The idle behavior.
-
-        Raises:
-            DwfLibraryError: An error occurred while executing the operation.
-        """
-        c_idle = typespec_ctypes.DwfAnalogOutIdle()
-        result = self.lib.FDwfAnalogOutIdleGet(self.hdwf, channel_index, c_idle)
-        if result != RESULT_SUCCESS:
-            raise self.dwf.exception()
-        idle = DwfAnalogOutIdle(c_idle.value)
-        return idle
+        wait_duration = c_wait_duration.value
+        return wait_duration
 
     def runInfo(self, channel_index: int) -> Tuple[float, float]:
         """Get run duration range, in seconds.
@@ -305,59 +237,43 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         secRun = c_secRun.value
         return secRun
 
-    def waitInfo(self, channel_index: int) -> Tuple[float, float]:
-        """Get wait info.
+    def repeatTriggerSet(self, channel_index: int, repeat_trigger_flag: bool) -> None:
+        """Set repeat trigger setting.
+
+        This setting determines if a new trigger must precede all runs, or only the first one.
+
+        Parameters:
+            channel_index (int): The |AnalogOut| channel.
+            repeat_trigger_flag (bool): The trigger repeat flag.
+
+        Raises:
+            DwfLibraryError: An error occurred while executing the operation.
+        """
+        result = self.lib.FDwfAnalogOutRepeatTriggerSet(self.hdwf, channel_index, repeat_trigger_flag)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+
+    def repeatTriggerGet(self, channel_index: int) -> bool:
+        """Get repeat trigger setting.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            Tuple[float, float]: The range of configurable wait durations.
+            bool: The currently configured repeat trigger setting.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
         """
-        c_secMin = typespec_ctypes.c_double()
-        c_secMax = typespec_ctypes.c_double()
-        result = self.lib.FDwfAnalogOutWaitInfo(self.hdwf, channel_index, c_secMin, c_secMax)
+        c_repeat_trigger_flag = typespec_ctypes.c_int()
+        result = self.lib.FDwfAnalogOutRepeatTriggerGet(
+            self.hdwf,
+            channel_index,
+            c_repeat_trigger_flag)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        secMin = c_secMin.value
-        secMax = c_secMax.value
-        return (secMin, secMax)
-
-    def waitSet(self, channel_index: int, wait_duration: float) -> None:
-        """Set wait state duration, in seconds.
-
-        Parameters:
-            channel_index (int): The |AnalogOut| channel.
-            wait_duration (float): The wait duration, in seconds.
-
-        Raises:
-            DwfLibraryError: An error occurred while executing the operation.
-        """
-        result = self.lib.FDwfAnalogOutWaitSet(self.hdwf, channel_index, wait_duration)
-        if result != RESULT_SUCCESS:
-            raise self.dwf.exception()
-
-    def waitGet(self, channel_index: int) -> float:
-        """Get wait state duration in seconds.
-
-        Parameters:
-            channel_index (int): The |AnalogOut| channel.
-
-        Returns:
-            float: The currently configured wait duration.
-
-        Raises:
-            DwfLibraryError: An error occurred while executing the operation.
-        """
-        c_wait_duration = typespec_ctypes.c_double()
-        result = self.lib.FDwfAnalogOutWaitGet(self.hdwf, channel_index, c_wait_duration)
-        if result != RESULT_SUCCESS:
-            raise self.dwf.exception()
-        wait_duration = c_wait_duration.value
-        return wait_duration
+        repeat_trigger_flag = bool(c_repeat_trigger_flag.value)
+        return repeat_trigger_flag
 
     def repeatInfo(self, channel_index: int) -> Tuple[int, int]:
         """Get repeat info.
@@ -432,92 +348,41 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         repeat_status = c_repeat_status.value
         return repeat_status
 
-    def limitationInfo(self, channel_index: int) -> Tuple[float, float]:
-        """Get limitation info.
+    def masterSet(self, channel_index: int, master_channel_index: int) -> None:
+        """Set master status.
+
+        Sets the state machine master of the channel generator.
 
         Parameters:
-            channel_index (int): The |AnalogOut| channel.
+            channel_index (int): The output channel for which to set the master setting.
+                Specify -1 to set all channels.
+            master_channel_index (int): The master channel index.
+
+        Raises:
+            DwfLibraryError: An error occurred while setting the value.
+        """
+        result = self.lib.FDwfAnalogOutMasterSet(self.hdwf, channel_index, master_channel_index)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+
+    def masterGet(self, channel_index: int) -> int:
+        """Get master status.
+
+        Parameters:
+            channel_index (int): The output channel for which to get the status.
 
         Returns:
-            Tuple[float, float]: The range of limitation values that can be configured.
+            int: The index of the master channel which the channel is configured to follow.
 
         Raises:
-            DwfLibraryError: An error occurred while executing the operation.
+            DwfLibraryError: An error occurred while getting the value.
         """
-        c_limitation_min = typespec_ctypes.c_double()
-        c_limitation_max = typespec_ctypes.c_double()
-        result = self.lib.FDwfAnalogOutLimitationInfo(self.hdwf, channel_index, c_limitation_min, c_limitation_max)
+        c_master_channel_index = typespec_ctypes.c_int()
+        result = self.lib.FDwfAnalogOutMasterGet(self.hdwf, channel_index, c_master_channel_index)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        limitation_min = c_limitation_min.value
-        limitation_max = c_limitation_max.value
-        return (limitation_min, limitation_max)
-
-    def limitationSet(self, channel_index: int, limitation: float) -> None:
-        """Set limitation value.
-
-        Parameters:
-            channel_index (int): The |AnalogOut| channel.
-            limitation (float): The limitation value, in [V] or [A].
-
-        Raises:
-            DwfLibraryError: An error occurred while executing the operation.
-        """
-        result = self.lib.FDwfAnalogOutLimitationSet(self.hdwf, channel_index, limitation)
-        if result != RESULT_SUCCESS:
-            raise self.dwf.exception()
-
-    def limitationGet(self, channel_index: int) -> float:
-        """Get limitation value (in Volts or Amps).
-
-        Parameters:
-            channel_index (int): The |AnalogOut| channel.
-
-        Returns:
-            float: The currently configured limitation.
-
-        Raises:
-            DwfLibraryError: An error occurred while executing the operation.
-        """
-        c_limitation = typespec_ctypes.c_double()
-        result = self.lib.FDwfAnalogOutLimitationGet(self.hdwf, channel_index, c_limitation)
-        if result != RESULT_SUCCESS:
-            raise self.dwf.exception()
-        limitation = c_limitation.value
-        return limitation
-
-    def customAMFMEnableSet(self, channel_index: int, enable: bool) -> None:
-        """Set custom AM/FM enable status.
-
-        Parameters:
-            channel_index (int): The |AnalogOut| channel.
-            enable (bool): The custom AM/FM enable setting.
-
-        Raises:
-            DwfLibraryError: An error occurred while executing the operation.
-        """
-        result = self.lib.FDwfAnalogOutCustomAMFMEnableSet(self.hdwf, channel_index, int(enable))
-        if result != RESULT_SUCCESS:
-            raise self.dwf.exception()
-
-    def customAMFMEnableGet(self, channel_index: int) -> bool:
-        """Get custom AM/FM enable status.
-
-        Parameters:
-            channel_index (int): The |AnalogOut| channel.
-
-        Returns:
-            bool: The custom AM/FM enable state.
-
-        Raises:
-            DwfLibraryError: An error occurred while executing the operation.
-        """
-        c_enable = typespec_ctypes.c_int()
-        result = self.lib.FDwfAnalogOutCustomAMFMEnableGet(self.hdwf, channel_index, c_enable)
-        if result != RESULT_SUCCESS:
-            raise self.dwf.exception()
-        enable = bool(c_enable.value)
-        return enable
+        master_channel_index = c_master_channel_index.value
+        return master_channel_index
 
     ####################################################################################################################
     #                                                                                                                  #
@@ -618,43 +483,190 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         trigger_slope = DwfTriggerSlope(c_trigger_slope.value)
         return trigger_slope
 
-    def repeatTriggerSet(self, channel_index: int, repeat_trigger_flag: bool) -> None:
-        """Set repeat trigger setting.
+    ####################################################################################################################
+    #                                                                                                                  #
+    #                                               PER-CHANNEL OUTPUT SETTINGS                                        #
+    #                                                                                                                  #
+    ####################################################################################################################
 
-        This setting determines if a new trigger must precede all runs, or only the first one.
+    def modeSet(self, channel_index: int, mode: DwfAnalogOutMode) -> None:
+        """Set analog output mode.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
-            repeat_trigger_flag (bool): The trigger repeat flag.
+            mode (DwfAnalogOutMode): The mode.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
         """
-        result = self.lib.FDwfAnalogOutRepeatTriggerSet(self.hdwf, channel_index, repeat_trigger_flag)
+        result = self.lib.FDwfAnalogOutModeSet(self.hdwf, channel_index, mode.value)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def repeatTriggerGet(self, channel_index: int) -> bool:
-        """Get repeat trigger setting.
+    def modeGet(self, channel_index: int) -> DwfAnalogOutMode:
+        """Get analog output mode.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            bool: The currently configured repeat trigger setting.
+            DwfAnalogOutMode: The currently configured analog output mode.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
         """
-        c_repeat_trigger_flag = typespec_ctypes.c_int()
-        result = self.lib.FDwfAnalogOutRepeatTriggerGet(
-            self.hdwf,
-            channel_index,
-            c_repeat_trigger_flag)
+        c_mode = typespec_ctypes.DwfAnalogOutMode()
+        result = self.lib.FDwfAnalogOutModeGet(self.hdwf, channel_index, c_mode)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        repeat_trigger_flag = bool(c_repeat_trigger_flag.value)
-        return repeat_trigger_flag
+        mode = DwfAnalogOutMode(c_mode.value)
+        return mode
+
+    def idleInfo(self, channel_index: int) -> List[DwfAnalogOutIdle]:
+        """Get idle info.
+
+        Parameters:
+            channel_index (int): The |AnalogOut| channel.
+
+        Returns:
+            List[DwfAnalogOutIdle]: A list of options for the channel behavior when idle.
+
+        Raises:
+            DwfLibraryError: An error occurred while executing the operation.
+        """
+        c_idle_bitset = typespec_ctypes.c_int()
+        result = self.lib.FDwfAnalogOutIdleInfo(self.hdwf, channel_index, c_idle_bitset)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+        idle_bitset = c_idle_bitset.value
+        idle_list = [idle for idle in DwfAnalogOutIdle if idle_bitset & (1 << idle.value)]
+        return idle_list
+
+    def idleSet(self, channel_index: int, idle: DwfAnalogOutIdle) -> None:
+        """Set idle behavior.
+
+        Parameters:
+            channel_index (int): The |AnalogOut| channel.
+            idle (DwfAnalogOutIdle): The idle setting.
+
+        Raises:
+            DwfLibraryError: An error occurred while executing the operation.
+        """
+        result = self.lib.FDwfAnalogOutIdleSet(self.hdwf, channel_index, idle.value)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+
+    def idleGet(self, channel_index: int) -> DwfAnalogOutIdle:
+        """Get idle behavior.
+
+        Parameters:
+            channel_index (int): The |AnalogOut| channel.
+
+        Returns:
+            DwfAnalogOutIdle: The idle behavior.
+
+        Raises:
+            DwfLibraryError: An error occurred while executing the operation.
+        """
+        c_idle = typespec_ctypes.DwfAnalogOutIdle()
+        result = self.lib.FDwfAnalogOutIdleGet(self.hdwf, channel_index, c_idle)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+        idle = DwfAnalogOutIdle(c_idle.value)
+        return idle
+
+    def limitationInfo(self, channel_index: int) -> Tuple[float, float]:
+        """Get limitation info.
+
+        Parameters:
+            channel_index (int): The |AnalogOut| channel.
+
+        Returns:
+            Tuple[float, float]: The range of limitation values that can be configured.
+
+        Raises:
+            DwfLibraryError: An error occurred while executing the operation.
+        """
+        c_limitation_min = typespec_ctypes.c_double()
+        c_limitation_max = typespec_ctypes.c_double()
+        result = self.lib.FDwfAnalogOutLimitationInfo(self.hdwf, channel_index, c_limitation_min, c_limitation_max)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+        limitation_min = c_limitation_min.value
+        limitation_max = c_limitation_max.value
+        return (limitation_min, limitation_max)
+
+    def limitationSet(self, channel_index: int, limitation: float) -> None:
+        """Set limitation value.
+
+        Parameters:
+            channel_index (int): The |AnalogOut| channel.
+            limitation (float): The limitation value, in [V] or [A].
+
+        Raises:
+            DwfLibraryError: An error occurred while executing the operation.
+        """
+        result = self.lib.FDwfAnalogOutLimitationSet(self.hdwf, channel_index, limitation)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+
+    def limitationGet(self, channel_index: int) -> float:
+        """Get limitation value (in Volts or Amps).
+
+        Parameters:
+            channel_index (int): The |AnalogOut| channel.
+
+        Returns:
+            float: The currently configured limitation.
+
+        Raises:
+            DwfLibraryError: An error occurred while executing the operation.
+        """
+        c_limitation = typespec_ctypes.c_double()
+        result = self.lib.FDwfAnalogOutLimitationGet(self.hdwf, channel_index, c_limitation)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+        limitation = c_limitation.value
+        return limitation
+
+    ####################################################################################################################
+    #                                                                                                                  #
+    #                                           PER-CHANNEL MISCELLANEOUS SETTINGS                                     #
+    #                                                                                                                  #
+    ####################################################################################################################
+
+    def customAMFMEnableSet(self, channel_index: int, enable: bool) -> None:
+        """Set custom AM/FM enable status.
+
+        Parameters:
+            channel_index (int): The |AnalogOut| channel.
+            enable (bool): The custom AM/FM enable setting.
+
+        Raises:
+            DwfLibraryError: An error occurred while executing the operation.
+        """
+        result = self.lib.FDwfAnalogOutCustomAMFMEnableSet(self.hdwf, channel_index, int(enable))
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+
+    def customAMFMEnableGet(self, channel_index: int) -> bool:
+        """Get custom AM/FM enable status.
+
+        Parameters:
+            channel_index (int): The |AnalogOut| channel.
+
+        Returns:
+            bool: The custom AM/FM enable state.
+
+        Raises:
+            DwfLibraryError: An error occurred while executing the operation.
+        """
+        c_enable = typespec_ctypes.c_int()
+        result = self.lib.FDwfAnalogOutCustomAMFMEnableGet(self.hdwf, channel_index, c_enable)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+        enable = bool(c_enable.value)
+        return enable
 
     ####################################################################################################################
     #                                                                                                                  #
@@ -986,7 +998,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         The *symmetry* value alters the waveform shape function of the node.
 
         The *symmetry* value ranges from 0 to 100 for most waveform shape functions, except for the
-        :py:attr:`~pydwf.core.auxiliary.enum_types.DwfAnalogOutFunction.SinePower` function,
+        :py:attr:`~pydwf.core.auxiliary.enum_types.DwfAnalogOutFunction.SinePower` waveform shape function.
         where it ranges from -100 to 100.
 
         Parameters:
@@ -1332,7 +1344,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            List[DwfAnalogOutFunction]: The currently configured function.
+            DwfAnalogOutFunction: The currently configured waveform shape function.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
