@@ -25,8 +25,8 @@ class DeviceEnumeration(AbstractDwfLibrarySubApi):
     def enumerateDevices(self, enum_filter: Optional[DwfEnumFilter] = None) -> int:
         """Build an internal list of available Digilent Waveforms devices and return the count of devices found.
 
-        This function must be called before using other |DeviceEnumeration| methods described below, because they
-        obtain information about the enumerated devices from the internal device list built by this method.
+        This method must be called before using other |DeviceEnumeration| methods described below, because they
+        obtain information about the enumerated devices from the internal device list that is built by this method.
 
         Note:
             This method can take several seconds to complete.
@@ -36,10 +36,10 @@ class DeviceEnumeration(AbstractDwfLibrarySubApi):
                 If None, enumerate all devices.
 
         Returns:
-            int: The number of devices detected.
+            int: The number of Digilent Waveforms devices detected.
 
         Raises:
-            DwfLibraryError: The devices cannot be enumerated.
+            DwfLibraryError: The Digilent Waveforms devices cannot be enumerated.
         """
         if enum_filter is None:
             enum_filter = DwfEnumFilter.All
@@ -52,21 +52,21 @@ class DeviceEnumeration(AbstractDwfLibrarySubApi):
         return device_count
 
     def deviceType(self, device_index: int) -> Tuple[int, int]:
-        """Return the device ID and version (hardware revision) of the selected device.
+        """Return the device ID and version (hardware revision) of the selected Digilent Waveforms device.
 
         Note:
-            This function returns the integer values as reported by the *FDwfEnumDeviceType* function
+            This method returns the integer values as reported by the *FDwfEnumDeviceType* function
             and does not cast them to |DwfDeviceID:link| and |DwfDeviceVersion:link| enumeration types.
 
             This is done to prevent unknown devices from raising an exception.
 
         Parameters:
-            device_index (int): Zero-based index of the previously enumerated device
+            device_index (int): Zero-based index of the previously enumerated Digilent Waveforms device
                 (see the :py:meth:`enumerateDevices` method).
 
         Returns:
             Tuple[int, int]: A tuple of the |DwfDeviceID:link| and |DwfDeviceVersion:link| integer
-            values of the selected device.
+            values of the selected Digilent Waveforms device.
 
         Raises:
             DwfLibraryError: The device type and version cannot be retrieved.
@@ -83,17 +83,17 @@ class DeviceEnumeration(AbstractDwfLibrarySubApi):
         return (device_id, device_revision)
 
     def deviceIsOpened(self, device_index: int) -> bool:
-        """Check if the specified device is already opened by this or any other process.
+        """Check if the specified Digilent Waveforms device is already opened by this or any other process.
 
         Parameters:
-            device_index (int): Zero-based index of the previously enumerated device
+            device_index (int): Zero-based index of the previously enumerated Digilent Waveforms device
                 (see the :py:meth:`enumerateDevices` method).
 
         Returns:
-            bool: True if the device is already opened, False otherwise.
+            bool: True if the Digilent Waveforms device is already opened, False otherwise.
 
         Raises:
-            DwfLibraryError: The open state of the device cannot be retrieved.
+            DwfLibraryError: The open state of the Digilent Waveforms device cannot be retrieved.
         """
         c_is_used = typespec_ctypes.c_int()
         result = self.lib.FDwfEnumDeviceIsOpened(device_index, c_is_used)
@@ -103,18 +103,18 @@ class DeviceEnumeration(AbstractDwfLibrarySubApi):
         return is_used
 
     def userName(self, device_index: int) -> str:
-        """Retrieve the user name of the selected device.
+        """Retrieve the user name of the selected Digilent Waveforms device.
 
         Parameters:
-            device_index (int): Zero-based index of the previously enumerated device
+            device_index (int): Zero-based index of the previously enumerated Digilent Waveforms device
                 (see the :py:meth:`enumerateDevices` method).
 
         Returns:
-            str: The user name of the device, which is a short name indicating the device type
-            (e.g., "Discovery2", "DDiscovery").
+            str: The user name of the Digilent Waveforms device, which is a short name indicating the
+            device type (e.g., "Discovery2", "DDiscovery").
 
         Raises:
-            DwfLibraryError: The user name of the device cannot be retrieved.
+            DwfLibraryError: The user name of the Digilent Waveforms device cannot be retrieved.
         """
         c_username = ctypes.create_string_buffer(32)
         result = self.lib.FDwfEnumUserName(device_index, c_username)
@@ -124,18 +124,18 @@ class DeviceEnumeration(AbstractDwfLibrarySubApi):
         return username
 
     def deviceName(self, device_index: int) -> str:
-        """Retrieve the device name of the selected device.
+        """Retrieve the device name of the selected Digilent Waveforms device.
 
         Parameters:
-            device_index (int): Zero-based index of the previously enumerated device
+            device_index (int): Zero-based index of the previously enumerated Digilent Waveforms device
                 (see the :py:meth:`enumerateDevices` method).
 
         Returns:
-            str: The device name of the device, which is a long name denoting the device type
-            (e.g., "Analog Discovery 2", "Digital Discovery").
+            str: The device name of the Digilent Waveforms device, which is a long name denoting the
+            device type (e.g., "Analog Discovery 2", "Digital Discovery").
 
         Raises:
-            DwfLibraryError: The device name of the device cannot be retrieved.
+            DwfLibraryError: The device name of the Digilent Waveforms device cannot be retrieved.
         """
         c_device_name = ctypes.create_string_buffer(32)
         result = self.lib.FDwfEnumDeviceName(device_index, c_device_name)
@@ -145,19 +145,19 @@ class DeviceEnumeration(AbstractDwfLibrarySubApi):
         return device_name
 
     def serialNumber(self, device_index: int) -> str:
-        """Retrieve the 12-digit, unique serial number of the enumerated device.
+        """Retrieve the 12-digit, unique serial number of the enumerated Digilent Waveforms device.
 
         Parameters:
-            device_index (int): Zero-based index of the previously enumerated device
+            device_index (int): Zero-based index of the previously enumerated Digilent Waveforms device
                 (see the :py:meth:`enumerateDevices` method).
 
         Returns:
-            str: The 12 hex-digit unique serial number of the device.
+            str: The 12 hex-digit unique serial number of the Digilent Waveforms device.
 
             The 'SN:' prefix returned by the underlying C API function is discarded.
 
         Raises:
-            DwfLibraryError: The serial number of the device cannot be retrieved.
+            DwfLibraryError: The serial number of the Digilent Waveforms device cannot be retrieved.
             PyDwfError: The serial number returned by the library isn't of the form 'SN:XXXXXXXXXXXX'.
         """
         c_serial = ctypes.create_string_buffer(32)
@@ -173,20 +173,20 @@ class DeviceEnumeration(AbstractDwfLibrarySubApi):
         return serial
 
     def enumerateConfigurations(self, device_index: int) -> int:
-        """Build an internal list of detected configurations for the specified device.
+        """Build an internal list of detected configurations for the specified Digilent Waveforms device.
 
-        This function must be called before using the :py:meth:`configInfo` method described below,
-        because that method obtains information from the internal device configuration list built by this method.
+        This method must be called before using the :py:meth:`configInfo` method described below, because
+        that method obtains information from the internal device configuration list that is built by this method.
 
         Parameters:
-            device_index (int): Zero-based index of the previously enumerated device
+            device_index (int): Zero-based index of the previously enumerated Digilent Waveforms device
                 (see the :py:meth:`enumerateDevices` method).
 
         Returns:
-            int: The count of configurations of the device.
+            int: The count of configurations of the Digilent Waveforms device.
 
         Raises:
-            DwfLibraryError: The configuration list of the device cannot be retrieved.
+            DwfLibraryError: The configuration list of the Digilent Waveforms device cannot be retrieved.
         """
         c_config_count = typespec_ctypes.c_int()
         result = self.lib.FDwfEnumConfig(device_index, c_config_count)
@@ -196,7 +196,7 @@ class DeviceEnumeration(AbstractDwfLibrarySubApi):
         return config_count
 
     def _configInfoString(self, config_index: int, info: DwfEnumConfigInfo, max_size: int) -> str:
-        """Return configuration info, as string."""
+        """Return Digilent Waveforms device configuration info for strings."""
 
         c_configuration_parameter_value = ctypes.create_string_buffer(max_size)
         result = self.lib.FDwfEnumConfigInfo(
@@ -208,7 +208,7 @@ class DeviceEnumeration(AbstractDwfLibrarySubApi):
         return configuration_parameter_value
 
     def configInfo(self, config_index: int, info: DwfEnumConfigInfo) -> Union[int, str]:
-        """Return information about a configuration.
+        """Return information about Digilent Waveforms device configuration.
 
         Parameters:
             config_index (int): Zero-based index of the previously enumerated configuration
@@ -220,7 +220,7 @@ class DeviceEnumeration(AbstractDwfLibrarySubApi):
             Union[int, str]: The value of the selected configuration parameter, of the selected configuration.
 
         Raises:
-            DwfLibraryError: The configuration info of the device cannot be retrieved.
+            DwfLibraryError: The configuration info of the Digilent Waveforms device cannot be retrieved.
         """
 
         if info == DwfEnumConfigInfo.TooltipText:
@@ -237,10 +237,10 @@ class DeviceEnumeration(AbstractDwfLibrarySubApi):
         return configuration_parameter_value
 
     def analogInChannels(self, device_index: int) -> int:
-        """Return the analog input channel count of the selected device.
+        """Return the analog input channel count of the selected Digilent Waveforms device.
 
         Warning:
-            This function is obsolete.
+            This method is obsolete.
 
             Use either of the following instead:
 
@@ -249,14 +249,14 @@ class DeviceEnumeration(AbstractDwfLibrarySubApi):
             * |AnalogIn.channelCount:link|
 
         Parameters:
-            device_index (int): Zero-based index of the previously enumerated device
+            device_index (int): Zero-based index of the previously enumerated Digilent Waveforms device
                 (see the :py:meth:`enumerateDevices` method).
 
         Returns:
-            int: The number of analog input channels of the device.
+            int: The number of analog input channels of the Digilent Waveforms device.
 
         Raises:
-            DwfLibraryError: The analog-in channel count of the device cannot be retrieved.
+            DwfLibraryError: The analog-in channel count of the Digilent Waveforms device cannot be retrieved.
         """
         c_channels = typespec_ctypes.c_int()
         result = self.lib.FDwfEnumAnalogInChannels(device_index, c_channels)
@@ -266,10 +266,10 @@ class DeviceEnumeration(AbstractDwfLibrarySubApi):
         return channels
 
     def analogInBufferSize(self, device_index: int) -> int:
-        """Retrieve the analog input buffer size of the selected device.
+        """Retrieve the analog input buffer size of the selected Digilent Waveforms device.
 
         Warning:
-            This function is obsolete.
+            This method is obsolete.
 
             Use either of the following instead:
 
@@ -278,14 +278,14 @@ class DeviceEnumeration(AbstractDwfLibrarySubApi):
             * |AnalogIn.bufferSizeGet:link|
 
         Parameters:
-            device_index (int): Zero-based index of the previously enumerated device
+            device_index (int): Zero-based index of the previously enumerated Digilent Waveforms device
                 (see the :py:meth:`enumerateDevices` method).
 
         Returns:
-            int: The analog input buffer size of the selected device.
+            int: The analog input buffer size of the selected Digilent Waveforms device.
 
         Raises:
-            DwfLibraryError: The analog-in buffer size of the device cannot be retrieved.
+            DwfLibraryError: The analog-in buffer size of the Digilent Waveforms device cannot be retrieved.
         """
         c_buffer_size = typespec_ctypes.c_int()
         result = self.lib.FDwfEnumAnalogInBufferSize(device_index, c_buffer_size)
@@ -295,22 +295,22 @@ class DeviceEnumeration(AbstractDwfLibrarySubApi):
         return buffer_size
 
     def analogInBits(self, device_index: int) -> int:
-        """Retrieve the analog input bit resolution of the selected device.
+        """Retrieve the analog input bit resolution of the selected Digilent Waveforms device.
 
         Warning:
-            This function is obsolete.
+            This method is obsolete.
 
             Use |AnalogIn.bitsInfo:link| instead.
 
         Parameters:
-            device_index (int): Zero-based index of the previously enumerated device
+            device_index (int): Zero-based index of the previously enumerated Digilent Waveforms device
                 (see the :py:meth:`enumerateDevices` method).
 
         Returns:
-            int: The analog input bit resolution of the selected device.
+            int: The analog input bit resolution of the selected Digilent Waveforms device.
 
         Raises:
-            DwfLibraryError: The analog-in bit resolution of the device cannot be retrieved.
+            DwfLibraryError: The analog-in bit resolution of the Digilent Waveforms device cannot be retrieved.
         """
         c_num_bits = typespec_ctypes.c_int()
         result = self.lib.FDwfEnumAnalogInBits(device_index, c_num_bits)
@@ -320,22 +320,22 @@ class DeviceEnumeration(AbstractDwfLibrarySubApi):
         return num_bits
 
     def analogInFrequency(self, device_index: int) -> float:
-        """Retrieve the analog input sample frequency of the selected device.
+        """Retrieve the analog input sample frequency of the selected Digilent Waveforms device.
 
         Warning:
-            This function is obsolete.
+            This method is obsolete.
 
             Use |AnalogIn.frequencyInfo:link| instead.
 
         Parameters:
-            device_index (int): Zero-based index of the previously enumerated device
+            device_index (int): Zero-based index of the previously enumerated Digilent Waveforms device
                 (see the :py:meth:`enumerateDevices` method).
 
         Returns:
-            float: The analog input sample frequency of the selected device, in samples per second.
+            float: The analog input sample frequency of the selected Digilent Waveforms device, in samples per second.
 
         Raises:
-            DwfLibraryError: The analog input sample frequency of the device cannot be retrieved.
+            DwfLibraryError: The analog input sample frequency of the Digilent Waveforms device cannot be retrieved.
         """
         c_sample_frequency = typespec_ctypes.c_double()
         result = self.lib.FDwfEnumAnalogInFrequency(device_index, c_sample_frequency)
