@@ -80,7 +80,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
 
     ####################################################################################################################
     #                                                                                                                  #
-    #                                               STATUS VARIABLES                                                   #
+    #                                                 STATUS VARIABLES                                                 #
     #                                                                                                                  #
     ####################################################################################################################
 
@@ -270,6 +270,10 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return noise
 
     ####################################################################################################################
+    #                                                                                                                  #
+    #                                            ACQUISITION TIMING SETTINGS                                           #
+    #                                                                                                                  #
+    ####################################################################################################################
 
     def internalClockInfo(self) -> float:
         """Get internal clock frequency, in Hz.
@@ -334,8 +338,6 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         clock_source = DwfDigitalInClockSource(c_clock_source.value)
         return clock_source
 
-    ####################################################################################################################
-
     def dividerInfo(self) -> int:
         """Get divider info.
 
@@ -382,6 +384,57 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         return divider
 
     ####################################################################################################################
+    #                                                                                                                  #
+    #                                                ACQUISITION SETTINGS                                              #
+    #                                                                                                                  #
+    ####################################################################################################################
+
+    def acquisitionModeInfo(self) -> List[DwfAcquisitionMode]:
+        """Get digital-in acquisition mode info.
+
+        Returns:
+            List[DwfAcquisitionMode]: A list of valid acquisition modes.
+
+        Raises:
+            DwfLibraryError: An error occurred while executing the operation.
+        """
+        c_acquisition_mode_bitset = typespec_ctypes.c_int()
+        result = self.lib.FDwfDigitalInAcquisitionModeInfo(self.hdwf, c_acquisition_mode_bitset)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+        acquisition_mode_bitset = c_acquisition_mode_bitset.value
+        acquisition_mode_list = [acquisition_mode for acquisition_mode in DwfAcquisitionMode
+                                 if acquisition_mode_bitset & (1 << acquisition_mode.value)]
+        return acquisition_mode_list
+
+    def acquisitionModeSet(self, acquisition_mode: DwfAcquisitionMode) -> None:
+        """Set acquisition mode.
+
+        Parameters:
+            acquisition_mode (DwfAcquisitionMode): The acquisition mode to be configured.
+
+        Raises:
+            DwfLibraryError: An error occurred while executing the operation.
+        """
+        result = self.lib.FDwfDigitalInAcquisitionModeSet(self.hdwf, acquisition_mode.value)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+
+    def acquisitionModeGet(self) -> DwfAcquisitionMode:
+        """Get acquisition mode.
+
+        Returns:
+            DwfAcquisitionMode: The currently active acquisition mode.
+
+        Raises:
+            DwfLibraryError: An error occurred while executing the operation.
+        """
+        c_acquisition_mode = typespec_ctypes.DwfAcquisitionMode()
+        result = self.lib.FDwfDigitalInAcquisitionModeGet(self.hdwf, c_acquisition_mode)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+        acquisition_mode = DwfAcquisitionMode(c_acquisition_mode.value)
+        return acquisition_mode
 
     def bitsInfo(self) -> int:
         """Get bits info.
@@ -399,8 +452,6 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         num_bits = c_num_bits.value
         return num_bits
 
-    ####################################################################################################################
-
     def sampleFormatSet(self, num_bits: int) -> None:
         """Set sample format.
 
@@ -448,8 +499,6 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    ####################################################################################################################
-
     def bufferSizeInfo(self) -> int:
         """Get buffer size info.
 
@@ -577,56 +626,38 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         compression_bits = c_compression_bits.value
         return compression_bits
 
-    def acquisitionModeInfo(self) -> List[DwfAcquisitionMode]:
-        """Get digital-in acquisition mode info.
-
-        Returns:
-            List[DwfAcquisitionMode]: A list of valid acquisition modes.
-
-        Raises:
-            DwfLibraryError: An error occurred while executing the operation.
-        """
-        c_acquisition_mode_bitset = typespec_ctypes.c_int()
-        result = self.lib.FDwfDigitalInAcquisitionModeInfo(self.hdwf, c_acquisition_mode_bitset)
-        if result != RESULT_SUCCESS:
-            raise self.dwf.exception()
-        acquisition_mode_bitset = c_acquisition_mode_bitset.value
-        acquisition_mode_list = [acquisition_mode for acquisition_mode in DwfAcquisitionMode
-                                 if acquisition_mode_bitset & (1 << acquisition_mode.value)]
-        return acquisition_mode_list
-
-    def acquisitionModeSet(self, acquisition_mode: DwfAcquisitionMode) -> None:
-        """Set acquisition mode.
+    def triggerPrefillSet(self, samples_before_trigger: int) -> None:
+        """Set trigger prefill, in samples.
 
         Parameters:
-            acquisition_mode (DwfAcquisitionMode): The acquisition mode to be configured.
+            samples_before_trigger (int): The prefill count, in samples.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
         """
-        result = self.lib.FDwfDigitalInAcquisitionModeSet(self.hdwf, acquisition_mode.value)
+        result = self.lib.FDwfDigitalInTriggerPrefillSet(self.hdwf, samples_before_trigger)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def acquisitionModeGet(self) -> DwfAcquisitionMode:
-        """Get acquisition mode.
+    def triggerPrefillGet(self) -> int:
+        """Get trigger prefill, in samples.
 
         Returns:
-            DwfAcquisitionMode: The currently active acquisition mode.
+            int: The trigger prefill count, in samples.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
         """
-        c_acquisition_mode = typespec_ctypes.DwfAcquisitionMode()
-        result = self.lib.FDwfDigitalInAcquisitionModeGet(self.hdwf, c_acquisition_mode)
+        c_samples_before_trigger = typespec_ctypes.c_unsigned_int()
+        result = self.lib.FDwfDigitalInTriggerPrefillGet(self.hdwf, c_samples_before_trigger)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        acquisition_mode = DwfAcquisitionMode(c_acquisition_mode.value)
-        return acquisition_mode
+        samples_before_trigger = c_samples_before_trigger.value
+        return samples_before_trigger
 
     ####################################################################################################################
     #                                                                                                                  #
-    #                                         INSTRUMENT TRIGGER CONFIGURATION                                         #
+    #                                                TRIGGER CONFIGURATION                                             #
     #                                                                                                                  #
     ####################################################################################################################
 
@@ -634,7 +665,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         """Get trigger source info.
 
         Note:
-            This function is OBSOLETE. Use the generic :py:meth:`DeviceControl.triggerInfo()` method instead.
+            This method is obsolete. Use the generic :py:meth:`DeviceControl.triggerInfo()` method instead.
 
         Returns:
             List[DwfTriggerSource]: A list of valid trigger source options.
@@ -819,35 +850,6 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         trigger_slope = DwfTriggerSlope(c_trigger_slope.value)
         return trigger_slope
 
-    def triggerPrefillSet(self, samples_before_trigger: int) -> None:
-        """Set trigger prefill, in samples.
-
-        Parameters:
-            samples_before_trigger (int): The prefill count, in samples.
-
-        Raises:
-            DwfLibraryError: An error occurred while executing the operation.
-        """
-        result = self.lib.FDwfDigitalInTriggerPrefillSet(self.hdwf, samples_before_trigger)
-        if result != RESULT_SUCCESS:
-            raise self.dwf.exception()
-
-    def triggerPrefillGet(self) -> int:
-        """Get trigger prefill, in samples.
-
-        Returns:
-            int: The trigger prefill count, in samples.
-
-        Raises:
-            DwfLibraryError: An error occurred while executing the operation.
-        """
-        c_samples_before_trigger = typespec_ctypes.c_unsigned_int()
-        result = self.lib.FDwfDigitalInTriggerPrefillGet(self.hdwf, c_samples_before_trigger)
-        if result != RESULT_SUCCESS:
-            raise self.dwf.exception()
-        samples_before_trigger = c_samples_before_trigger.value
-        return samples_before_trigger
-
     def triggerInfo(self) -> Tuple[int, int, int, int]:
         """Get trigger info.
 
@@ -990,6 +992,10 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
     ####################################################################################################################
+    #                                                                                                                  #
+    #                                                   MISCELLANEOUS SETTINGS                                         #
+    #                                                                                                                  #
+    ####################################################################################################################
 
     def mixedSet(self, enable: bool) -> None:
         """Set mixed state.
@@ -1001,7 +1007,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             Figure out what this setting does.
 
         Note:
-            This function is OBSOLETE.
+            This method is obsolete.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
