@@ -24,6 +24,12 @@ class DigitalOut(AbstractDwfDeviceSubApi):
 
     # pylint: disable=too-many-public-methods
 
+    ####################################################################################################################
+    #                                                                                                                  #
+    #                                               INSTRUMENT CONTROL                                                 #
+    #                                                                                                                  #
+    ####################################################################################################################
+
     def reset(self) -> None:
         """Reset the digital-out instrument.
 
@@ -65,71 +71,81 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         status_ = DwfState(c_status.value)
         return status_
 
-    def internalClockInfo(self) -> float:
-        """Get digital-out clock frequency.
+    ####################################################################################################################
+    #                                                                                                                  #
+    #                                                    CHANNEL COUNT                                                 #
+    #                                                                                                                  #
+    ####################################################################################################################
+
+    def count(self) -> int:
+        """Get digital-out channel count.
 
         Returns:
-            float: The digital-out clock frequency, in Hz.
+            int: The number of digital output channels.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
         """
-        c_internal_clock_frequency = typespec_ctypes.c_double()
-        result = self.lib.FDwfDigitalOutInternalClockInfo(self.hdwf, c_internal_clock_frequency)
+        c_channel_count = typespec_ctypes.c_int()
+        result = self.lib.FDwfDigitalOutCount(self.hdwf, c_channel_count)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        internal_clock_frequency = c_internal_clock_frequency.value
-        return internal_clock_frequency
+        channel_count = c_channel_count.value
+        return channel_count
 
-    def triggerSourceInfo(self) -> List[DwfTriggerSource]:
-        """Get digital-out trigger source info.
+    ####################################################################################################################
+    #                                                                                                                  #
+    #                                                 STATE MACHINE SETTINGS                                           #
+    #                                                                                                                  #
+    ####################################################################################################################
 
-        Note:
-            This function is OBSOLETE. Use the generic DeviceControl.triggerInfo() method instead.
+    def waitInfo(self) -> Tuple[float, float]:
+        """Get minimal and maximal wait-time preceding digital-out pulse-sequence runs, in seconds.
 
         Returns:
-            List[DwfTriggerSource]: A list of possible choices for the trigger source.
+            Tuple[float, float]: A tuple containing the minimal and maximal configurable wait durations that should
+            precede a pulse-train output, expressed in seconds.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
         """
-        c_trigger_source_bitset = typespec_ctypes.c_int()
-        result = self.lib.FDwfDigitalOutTriggerSourceInfo(self.hdwf, c_trigger_source_bitset)
+        c_wait_duration_min = typespec_ctypes.c_double()
+        c_wait_duration_max = typespec_ctypes.c_double()
+        result = self.lib.FDwfDigitalOutWaitInfo(self.hdwf, c_wait_duration_min, c_wait_duration_max)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        trigger_source_bitset = c_trigger_source_bitset.value
-        trigger_source_list = [trigger_source for trigger_source in DwfTriggerSource
-                               if trigger_source_bitset & (1 << trigger_source.value)]
-        return trigger_source_list
+        wait_duration_min = c_wait_duration_min.value
+        wait_duration_max = c_wait_duration_max.value
+        return (wait_duration_min, wait_duration_max)
 
-    def triggerSourceSet(self, trigger_source: DwfTriggerSource) -> None:
-        """Set the trigger source.
+    def waitSet(self, wait_duration: float) -> None:
+        """Set wait duration before digital-out pulse-sequence runs, in seconds.
 
         Parameters:
-            trigger_source (DwfTriggerSource): The trigger source to be configured.
+            wait_duration (float): Digital-out wait duration, in seconds.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
         """
-        result = self.lib.FDwfDigitalOutTriggerSourceSet(self.hdwf, trigger_source.value)
+        result = self.lib.FDwfDigitalOutWaitSet(self.hdwf, wait_duration)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def triggerSourceGet(self) -> DwfTriggerSource:
-        """Get the currently active trigger source.
+    def waitGet(self) -> float:
+        """Get wait duration before digital-out pulse-sequence runs, in seconds.
 
         Returns:
-            DwfTriggerSource: The currently configured trigger source.
+            float: Digital-out wait duration, in seconds.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
         """
-        c_trigger_source = typespec_ctypes.DwfTriggerSource()
-        result = self.lib.FDwfDigitalOutTriggerSourceGet(self.hdwf, c_trigger_source)
+        c_wait_duration = typespec_ctypes.c_double()
+        result = self.lib.FDwfDigitalOutWaitGet(self.hdwf, c_wait_duration)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        trigger_source = DwfTriggerSource(c_trigger_source.value)
-        return trigger_source
+        wait_duration = c_wait_duration.value
+        return wait_duration
 
     def runInfo(self) -> Tuple[float, float]:
         """Get minimal and maximal duration for a single digital-out pulse sequence run, in seconds.
@@ -205,57 +221,38 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
 
         if not c_run_status.value.is_integer():
-            raise PyDwfError("FDwfDigitalOutRunStatus returned {}; an integer was expected.".format(c_run_status.value))
+            raise PyDwfError("Bad c_run_status value.")
+
         run_status = int(c_run_status.value)
         return run_status
 
-    def waitInfo(self) -> Tuple[float, float]:
-        """Get minimal and maximal wait-time preceding digital-out pulse-sequence runs, in seconds.
-
-        Returns:
-            Tuple[float, float]: A tuple containing the minimal and maximal configurable wait durations that should
-            precede a pulse-train output, expressed in seconds.
-
-        Raises:
-            DwfLibraryError: An error occurred while executing the operation.
-        """
-        c_wait_duration_min = typespec_ctypes.c_double()
-        c_wait_duration_max = typespec_ctypes.c_double()
-        result = self.lib.FDwfDigitalOutWaitInfo(self.hdwf, c_wait_duration_min, c_wait_duration_max)
-        if result != RESULT_SUCCESS:
-            raise self.dwf.exception()
-        wait_duration_min = c_wait_duration_min.value
-        wait_duration_max = c_wait_duration_max.value
-        return (wait_duration_min, wait_duration_max)
-
-    def waitSet(self, wait_duration: float) -> None:
-        """Set wait duration before digital-out pulse-sequence runs, in seconds.
+    def repeatTriggerSet(self, repeat_trigger_flag: bool) -> None:
+        """Specify if each pulse sequence run should wait for its own trigger.
 
         Parameters:
-            wait_duration (float): Digital-out wait duration, in seconds.
+            repeat_trigger_flag (bool): If True, not only the first, both also every successive run of the
+                pulse output sequence will wait until it receives a trigger.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
         """
-        result = self.lib.FDwfDigitalOutWaitSet(self.hdwf, wait_duration)
+        result = self.lib.FDwfDigitalOutRepeatTriggerSet(self.hdwf, repeat_trigger_flag)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def waitGet(self) -> float:
-        """Get wait duration before digital-out pulse-sequence runs, in seconds.
+    def repeatTriggerGet(self) -> bool:
+        """Get if each pulse sequence run should wait for its own trigger.
 
         Returns:
-            float: Digital-out wait duration, in seconds.
-
-        Raises:
-            DwfLibraryError: An error occurred while executing the operation.
+            bool: If True, not only the first, both also every successive run of the pulse output sequence
+            will wait until it receives a trigger.
         """
-        c_wait_duration = typespec_ctypes.c_double()
-        result = self.lib.FDwfDigitalOutWaitGet(self.hdwf, c_wait_duration)
+        c_repeat_trigger = typespec_ctypes.c_int()
+        result = self.lib.FDwfDigitalOutRepeatTriggerGet(self.hdwf, c_repeat_trigger)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        wait_duration = c_wait_duration.value
-        return wait_duration
+        repeat_trigger_flag = bool(c_repeat_trigger.value)
+        return repeat_trigger_flag
 
     def repeatInfo(self) -> Tuple[int, int]:
         """Get minimal and maximal repeat count for digital-out pulse-sequence runs.
@@ -325,6 +322,62 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         repeat_status = c_repeat_status.value
         return repeat_status
 
+    ####################################################################################################################
+    #                                                                                                                  #
+    #                                                 TRIGGER CONFIGURATION                                            #
+    #                                                                                                                  #
+    ####################################################################################################################
+
+    def triggerSourceInfo(self) -> List[DwfTriggerSource]:
+        """Get digital-out trigger source info.
+
+        Note:
+            This method is obsolete. Use the generic DeviceControl.triggerInfo() method instead.
+
+        Returns:
+            List[DwfTriggerSource]: A list of possible choices for the trigger source.
+
+        Raises:
+            DwfLibraryError: An error occurred while executing the operation.
+        """
+        c_trigger_source_bitset = typespec_ctypes.c_int()
+        result = self.lib.FDwfDigitalOutTriggerSourceInfo(self.hdwf, c_trigger_source_bitset)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+        trigger_source_bitset = c_trigger_source_bitset.value
+        trigger_source_list = [trigger_source for trigger_source in DwfTriggerSource
+                               if trigger_source_bitset & (1 << trigger_source.value)]
+        return trigger_source_list
+
+    def triggerSourceSet(self, trigger_source: DwfTriggerSource) -> None:
+        """Set the trigger source.
+
+        Parameters:
+            trigger_source (DwfTriggerSource): The trigger source to be configured.
+
+        Raises:
+            DwfLibraryError: An error occurred while executing the operation.
+        """
+        result = self.lib.FDwfDigitalOutTriggerSourceSet(self.hdwf, trigger_source.value)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+
+    def triggerSourceGet(self) -> DwfTriggerSource:
+        """Get the currently active trigger source.
+
+        Returns:
+            DwfTriggerSource: The currently configured trigger source.
+
+        Raises:
+            DwfLibraryError: An error occurred while executing the operation.
+        """
+        c_trigger_source = typespec_ctypes.DwfTriggerSource()
+        result = self.lib.FDwfDigitalOutTriggerSourceGet(self.hdwf, c_trigger_source)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+        trigger_source = DwfTriggerSource(c_trigger_source.value)
+        return trigger_source
+
     def triggerSlopeSet(self, trigger_slope: DwfTriggerSlope) -> None:
         """Set the slope for the digital-out trigger.
 
@@ -354,49 +407,11 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         trigger_slope = DwfTriggerSlope(c_trigger_slope.value)
         return trigger_slope
 
-    def repeatTriggerSet(self, repeat_trigger_flag: bool) -> None:
-        """Specify if each pulse sequence run should wait for its own trigger.
-
-        Parameters:
-            repeat_trigger_flag (bool): If True, not only the first, both also every successive run of the
-                pulse output sequence will wait until it receives a trigger.
-
-        Raises:
-            DwfLibraryError: An error occurred while executing the operation.
-        """
-        result = self.lib.FDwfDigitalOutRepeatTriggerSet(self.hdwf, repeat_trigger_flag)
-        if result != RESULT_SUCCESS:
-            raise self.dwf.exception()
-
-    def repeatTriggerGet(self) -> bool:
-        """Get if each pulse sequence run should wait for its own trigger.
-
-        Returns:
-            bool: If True, not only the first, both also every successive run of the pulse output sequence
-            will wait until it receives a trigger.
-        """
-        c_repeat_trigger = typespec_ctypes.c_int()
-        result = self.lib.FDwfDigitalOutRepeatTriggerGet(self.hdwf, c_repeat_trigger)
-        if result != RESULT_SUCCESS:
-            raise self.dwf.exception()
-        repeat_trigger_flag = bool(c_repeat_trigger.value)
-        return repeat_trigger_flag
-
-    def count(self) -> int:
-        """Get digital-out channel count.
-
-        Returns:
-            int: The number of digital output channels.
-
-        Raises:
-            DwfLibraryError: An error occurred while executing the operation.
-        """
-        c_channel_count = typespec_ctypes.c_int()
-        result = self.lib.FDwfDigitalOutCount(self.hdwf, c_channel_count)
-        if result != RESULT_SUCCESS:
-            raise self.dwf.exception()
-        channel_count = c_channel_count.value
-        return channel_count
+    ####################################################################################################################
+    #                                                                                                                  #
+    #                                                    OUTPUT SETTINGS                                               #
+    #                                                                                                                  #
+    ####################################################################################################################
 
     def enableSet(self, channel_index: int, enable_flag: bool) -> None:
         """Enable or disable a digital-out channel.
@@ -581,6 +596,28 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         idle_mode = DwfDigitalOutIdle(c_idle_mode.value)
         return idle_mode
 
+    ####################################################################################################################
+    #                                                                                                                  #
+    #                                               OUTPUT PATTERN TIMING DEFINITION                                   #
+    #                                                                                                                  #
+    ####################################################################################################################
+
+    def internalClockInfo(self) -> float:
+        """Get digital-out clock frequency.
+
+        Returns:
+            float: The digital-out clock frequency, in Hz.
+
+        Raises:
+            DwfLibraryError: An error occurred while executing the operation.
+        """
+        c_internal_clock_frequency = typespec_ctypes.c_double()
+        result = self.lib.FDwfDigitalOutInternalClockInfo(self.hdwf, c_internal_clock_frequency)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+        internal_clock_frequency = c_internal_clock_frequency.value
+        return internal_clock_frequency
+
     def dividerInfo(self, channel_index: int) -> Tuple[int, int]:
         """Get divider value range.
 
@@ -603,39 +640,6 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         divider_max = c_divider_max.value
         return (divider_min, divider_max)
 
-    def dividerInitSet(self, channel_index: int, divider_init: int) -> None:
-        """Set initial divider value.
-
-        Parameters:
-            channel_index (int): The digital pin.
-            divider_init (int): The divider init setting.
-
-        Raises:
-            DwfLibraryError: An error occurred while executing the operation.
-        """
-        result = self.lib.FDwfDigitalOutDividerInitSet(self.hdwf, channel_index, divider_init)
-        if result != RESULT_SUCCESS:
-            raise self.dwf.exception()
-
-    def dividerInitGet(self, channel_index: int) -> int:
-        """Get currently configured initial divider value.
-
-        Parameters:
-            channel_index (int): The digital pin.
-
-        Returns:
-            int: The divider init setting.
-
-        Raises:
-            DwfLibraryError: An error occurred while executing the operation.
-        """
-        c_divider_init = typespec_ctypes.c_unsigned_int()
-        result = self.lib.FDwfDigitalOutDividerInitGet(self.hdwf, channel_index, c_divider_init)
-        if result != RESULT_SUCCESS:
-            raise self.dwf.exception()
-        divider_init = c_divider_init.value
-        return divider_init
-
     def dividerSet(self, channel_index: int, divider: int) -> None:
         """Set divider value.
 
@@ -669,6 +673,39 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         divider = c_divider.value
         return divider
 
+    def dividerInitSet(self, channel_index: int, divider_init: int) -> None:
+        """Set initial divider value.
+
+        Parameters:
+            channel_index (int): The digital pin.
+            divider_init (int): The divider init setting.
+
+        Raises:
+            DwfLibraryError: An error occurred while executing the operation.
+        """
+        result = self.lib.FDwfDigitalOutDividerInitSet(self.hdwf, channel_index, divider_init)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+
+    def dividerInitGet(self, channel_index: int) -> int:
+        """Get currently configured initial divider value.
+
+        Parameters:
+            channel_index (int): The digital pin.
+
+        Returns:
+            int: The divider init setting.
+
+        Raises:
+            DwfLibraryError: An error occurred while executing the operation.
+        """
+        c_divider_init = typespec_ctypes.c_unsigned_int()
+        result = self.lib.FDwfDigitalOutDividerInitGet(self.hdwf, channel_index, c_divider_init)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+        divider_init = c_divider_init.value
+        return divider_init
+
     def counterInfo(self, channel_index: int) -> Tuple[int, int]:
         """Get counter value range.
 
@@ -694,6 +731,42 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         counter_max = c_counter_max.value
         return (counter_min, counter_max)
 
+    def counterSet(self, channel_index: int, low_count: int, high_count: int) -> None:
+        """Set counter durations for both the low and high signal output levels.
+
+        Parameters:
+            channel_index (int): The digital pin.
+            low_count (int): The number of cycles the signal should be Low.
+            high_count (int): The number of cycles the signal should be High.
+
+        Raises:
+            DwfLibraryError: An error occurred while executing the operation.
+        """
+        result = self.lib.FDwfDigitalOutCounterSet(self.hdwf, channel_index, low_count, high_count)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+
+    def counterGet(self, channel_index: int) -> Tuple[int, int]:
+        """Get counter durations for both the low and high signal output levels.
+
+        Parameters:
+            channel_index (int): The digital pin.
+
+        Returns:
+            Tuple[int, int]: The number of cycles the signal should be Low, High.
+
+        Raises:
+            DwfLibraryError: An error occurred while executing the operation.
+        """
+        c_low_count = typespec_ctypes.c_unsigned_int()
+        c_high_count = typespec_ctypes.c_unsigned_int()
+        result = self.lib.FDwfDigitalOutCounterGet(self.hdwf, channel_index, c_low_count, c_high_count)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+        low_count = c_low_count.value
+        high_count = c_high_count.value
+        return (low_count, high_count)
+
     def counterInitSet(self, channel_index: int, high: bool, counter_init: int) -> None:
         """Set initial signal value and initial counter value.
 
@@ -737,41 +810,11 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         counter_init = c_counter_init.value
         return (high, counter_init)
 
-    def counterSet(self, channel_index: int, low_count: int, high_count: int) -> None:
-        """Set counter durations for both the low and high signal output levels.
-
-        Parameters:
-            channel_index (int): The digital pin.
-            low_count (int): The number of cycles the signal should be Low.
-            high_count (int): The number of cycles the signal should be High.
-
-        Raises:
-            DwfLibraryError: An error occurred while executing the operation.
-        """
-        result = self.lib.FDwfDigitalOutCounterSet(self.hdwf, channel_index, low_count, high_count)
-        if result != RESULT_SUCCESS:
-            raise self.dwf.exception()
-
-    def counterGet(self, channel_index: int) -> Tuple[int, int]:
-        """Get counter durations for both the low and high signal output levels.
-
-        Parameters:
-            channel_index (int): The digital pin.
-
-        Returns:
-            Tuple[int, int]: The number of cycles the signal should be Low, High.
-
-        Raises:
-            DwfLibraryError: An error occurred while executing the operation.
-        """
-        c_low_count = typespec_ctypes.c_unsigned_int()
-        c_high_count = typespec_ctypes.c_unsigned_int()
-        result = self.lib.FDwfDigitalOutCounterGet(self.hdwf, channel_index, c_low_count, c_high_count)
-        if result != RESULT_SUCCESS:
-            raise self.dwf.exception()
-        low_count = c_low_count.value
-        high_count = c_high_count.value
-        return (low_count, high_count)
+    ####################################################################################################################
+    #                                                                                                                  #
+    #                                                      DATA PLAYBACK                                               #
+    #                                                                                                                  #
+    ####################################################################################################################
 
     def dataInfo(self, channel_index: int) -> int:
         """Return the maximum buffer size for the specified |DigitalOut| channel,
