@@ -29,5 +29,5 @@ class AbstractDwfDeviceSubApi:
 
     @property
     def lib(self):
-        """Return the ctypes:link library."""
+        """Return the |ctypes:link| library."""
         return self.dwf.lib
